//+------------------------------------------------------------------+
//|                                                      bayes_3.mq5 |
//|                                  Copyright 2024, MetaQuotes Ltd. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2024, MetaQuotes Ltd."
#property link      "https://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\My\SignalWZ_19_.mqh>
//--- available trailing
#include <Expert\Trailing\My\TrailingWZ_19.mqh>
//--- available money management
#include <Expert\Money\My\MoneyWZ_19.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string Expert_Title               = "bayes_3"; // Document name
ulong        Expert_MagicNumber         = 29123;    //
bool         Expert_EveryTick           = false;    //
//--- inputs for main signal
input int    Signal_ThresholdOpen       = 10;       // Signal threshold value to open [0...100]
input int    Signal_ThresholdClose      = 10;       // Signal threshold value to close [0...100]
input double Signal_PriceLevel          = 0.0;      // Price level to execute a deal
input double Signal_StopLevel           = 50.0;     // Stop Loss level (in points)
input double Signal_TakeLevel           = 50.0;     // Take Profit level (in points)
input int    Signal_Expiration          = 4;        // Expiration of pending orders (in bars)
input int    Signal_BAYES_SeriesSize    = 30;       // BAYES(30,2,0) Series Size
input int    Signal_BAYES_LongCluster   = 2;        // BAYES(30,2,0) Long Cluster
input int    Signal_BAYES_ShortCluster  = 0;        // BAYES(30,2,0) Short Cluster
input double Signal_BAYES_Weight        = 1.0;      // BAYES(30,2,0) Weight [0...1.0]
//--- inputs for trailing
input int    Trailing_BAYES_SeriesSize  = 30;       // Series Size
input int    Trailing_BAYES_LongCluster = 2;        // Long Cluster
input int    Trailing_BAYES_ShortCluster = 0;       // Short Cluster
//--- inputs for money
input double Money_BAYES_DecreaseFactor = 3.0;      // Decrease factor
input double Money_BAYES_Percent        = 5.0;      // Percent
input int    Money_BAYES_SeriesSize     = 30;       // Series Size
input int    Money_BAYES_LongCluster    = 2;        // Long Cluster
input int    Money_BAYES_ShortCluster   = 0;        // Short Cluster
input double Money_BAYES_Condition      = 0.5;      // Condition
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
{
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(), Period(), Expert_EveryTick, Expert_MagicNumber))
   {  //--- failed
      printf(__FUNCTION__ + ": error initializing expert");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Creating signal
   CExpertSignal *signal = new CExpertSignal;
   if(signal == NULL)
   {  //--- failed
      printf(__FUNCTION__ + ": error creating signal");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalBAYES
   CSignalBAYES *filter0 = new CSignalBAYES;
   if(filter0 == NULL)
   {  //--- failed
      printf(__FUNCTION__ + ": error creating filter0");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.SeriesSize(Signal_BAYES_SeriesSize);
   filter0.LongCluster(Signal_BAYES_LongCluster);
   filter0.ShortCluster(Signal_BAYES_ShortCluster);
   filter0.Weight(Signal_BAYES_Weight);
//--- Creation of trailing object
   CTrailingBAYES *trailing = new CTrailingBAYES;
   if(trailing == NULL)
   {  //--- failed
      printf(__FUNCTION__ + ": error creating trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
   {  //--- failed
      printf(__FUNCTION__ + ": error initializing trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Set trailing parameters
   trailing.SeriesSize(Trailing_BAYES_SeriesSize);
   trailing.LongCluster(Trailing_BAYES_LongCluster);
   trailing.ShortCluster(Trailing_BAYES_ShortCluster);
//--- Creation of money object
   CMoneyBAYES *money = new CMoneyBAYES;
   if(money == NULL)
   {  //--- failed
      printf(__FUNCTION__ + ": error creating money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
   {  //--- failed
      printf(__FUNCTION__ + ": error initializing money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Set money parameters
   money.DecreaseFactor(Money_BAYES_DecreaseFactor);
   money.Percent(Money_BAYES_Percent);
   money.SeriesSize(Money_BAYES_SeriesSize);
   money.LongCluster(Money_BAYES_LongCluster);
   money.ShortCluster(Money_BAYES_ShortCluster);
   money.Condition(Money_BAYES_Condition);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
   {  //--- failed
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
   {  //--- failed
      printf(__FUNCTION__ + ": error initializing indicators");
      ExtExpert.Deinit();
      return(INIT_FAILED);
   }
//--- ok
   return(INIT_SUCCEEDED);
}
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
{  ExtExpert.Deinit();
}
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
{  ExtExpert.OnTick();
}
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
{  ExtExpert.OnTrade();
}
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
{  ExtExpert.OnTimer();
}
//+------------------------------------------------------------------+
